require "thor"
require "backlog_jp"
require "json"

class BacklogJp::Pj2JSON::CLI < Thor
  desc "version", "Puts version."
  def version
    puts BacklogJp::Pj2JSON::VERSION
  end

  desc "export", "Export project issues/comments to JSON."
  method_option :space, required: true
  method_option :api_key, required: true
  method_option :project_key, required: true
  method_option :output, required: true
  def export
    hash = {issues: []}

    # Collect data
    1.upto Float::INFINITY do |issue_key|
      begin
        issue = client.get("issues/#{options.project_key}-#{issue_key}")
        puts issue
        comments = client.get("issues/#{options.project_key}-#{issue_key}/comments", count: 100)
        puts comments
        issue[:comments] = comments
        hash[:issues] << issue
      rescue BacklogJp::Client::APIException => exception
        break if exception.message.include? "No Issue."
        abort
      end
    end

    File.open(options.output, "wb") do |file|
      file.puts JSON.pretty_generate(hash)
    end
  end

  private

  def client
    @client ||= BacklogJp::Client.new space: options.space, api_key: options.api_key
  end
end
